@@ -42,7 +42,7 @@ from requests import Request, Response
 from requests.exceptions import HTTPError
 from tqdm import tqdm
 
-from internetarchive import catalog
+from internetarchive import catalog, exceptions
 from internetarchive.auth import S3Auth
 from internetarchive.files import File
 from internetarchive.iarequest import MetadataRequest, S3Request
@@ -610,6 +610,7 @@ class Item(BaseItem):
                         if not any(fnmatch(f.get('name', ''), e) for e in exclude_patterns):
                             yield self.get_file(str(f.get('name')))
 
+    # ruff: noqa: PLR0912
     def download(self,
                  files: File | list[File] | None = None,
                  formats: str | list[str] | None = None,
@@ -774,7 +775,12 @@ class Item(BaseItem):
             if no_directory:
                 path = f.name
             else:
-                path = os.path.join(str(self.identifier), f.name)
+                # Use forward slash as logical separator even on Windows so that
+                # downstream sanitization treats backslashes inside remote filenames as data.
+                if os.name == 'nt':
+                    path = f'{self.identifier}/{f.name}'
+                else:
+                    path = os.path.join(str(self.identifier), f.name)
             if dry_run:
                 print(f.url)
                 continue
@@ -782,9 +788,18 @@ class Item(BaseItem):
                 ors = True
             else:
                 ors = False
-            r = f.download(path, verbose, ignore_existing, checksum, checksum_archive,
-                           destdir, retries, ignore_errors, fileobj, return_responses,
-                           no_change_timestamp, params, None, stdout, ors, timeout)
+            try:
+                r = f.download(path, verbose, ignore_existing, checksum, checksum_archive,
+                               destdir, retries, ignore_errors, fileobj, return_responses,
+                               no_change_timestamp, params, None, stdout, ors, timeout)
+            except exceptions.DirectoryTraversalError as exc:  # type: ignore
+                # Record error and continue; do not abort entire download batch.
+                msg = f'error: {exc}'
+                log.error(msg)
+                # Always surface to stderr so user sees the skip.
+                print(f' {msg}', file=sys.stderr)
+                errors.append(f.name)
+                continue
             if return_responses:
                 responses.append(r)
 
@@ -968,8 +983,7 @@ class Item(BaseItem):
                     retries_sleep: int | None = None,
                     debug: bool = False,
                     validate_identifier: bool = False,
-                    request_kwargs: MutableMapping | None = None,
-                    set_scanner: bool = True) -> Request | Response:
+                    request_kwargs: MutableMapping | None = None) -> Request | Response:
         """Upload a single file to an item. The item will be created
         if it does not exist.
 
@@ -1132,8 +1146,7 @@ class Item(BaseItem):
                                 file_metadata=file_metadata,
                                 access_key=access_key,
                                 secret_key=secret_key,
-                                queue_derive=queue_derive,
-                                set_scanner=set_scanner)
+                                queue_derive=queue_derive)
             return request
 
         if debug:
@@ -1235,8 +1248,7 @@ class Item(BaseItem):
                retries_sleep: int | None = None,
                debug: bool = False,
                validate_identifier: bool = False,
-               request_kwargs: dict | None = None,
-               set_scanner: bool = True) -> list[Request | Response]:
+               request_kwargs: dict | None = None) -> list[Request | Response]:
         r"""Upload files to an item. The item will be created if it
         does not exist.
 
@@ -1344,8 +1356,7 @@ class Item(BaseItem):
                                             retries_sleep=retries_sleep,
                                             debug=debug,
                                             validate_identifier=validate_identifier,
-                                            request_kwargs=request_kwargs,
-                                            set_scanner=set_scanner)
+                                            request_kwargs=request_kwargs)
                     responses.append(resp)
             else:
                 file_index += 1
@@ -1379,8 +1390,7 @@ class Item(BaseItem):
                                         retries_sleep=retries_sleep,
                                         debug=debug,
                                         validate_identifier=validate_identifier,
-                                        request_kwargs=request_kwargs,
-                                        set_scanner=set_scanner)
+                                        request_kwargs=request_kwargs)
                 responses.append(resp)
         return responses
 
