@@ -29,8 +29,10 @@ from __future__ import annotations
 
 import hashlib
 import os
+import platform
 import re
 import sys
+import warnings
 from collections.abc import Mapping
 from typing import Iterable
 from xml.dom.minidom import parseString
@@ -406,8 +408,8 @@ def is_valid_metadata_key(name: str) -> bool:
 
 
 def merge_dictionaries(
-    dict0: dict,
-    dict1: dict,
+    dict0: dict | None,
+    dict1: dict | None,
     keys_to_drop: Iterable | None = None,
 ) -> dict:
     """Merge two dictionaries.
@@ -425,12 +427,19 @@ def merge_dictionaries(
 
        :returns: A merged dictionary.
        """
-    new_dict = dict0.copy()
+    if dict0 is not None:
+        new_dict = dict0.copy()
+    else:
+        new_dict = {}
+
     if keys_to_drop is not None:
         for key in keys_to_drop:
             new_dict.pop(key, None)
+
     # Items from `dict1` take precedence over items from `dict0`.
-    new_dict.update(dict1)
+    if dict1 is not None:
+        new_dict.update(dict1)
+
     return new_dict
 
 
@@ -457,3 +466,264 @@ def is_valid_email(email):
     # Ensures the TLD has at least 2 characters
     pattern = r'^[a-zA-Z0-9_.+-]+@[a-zA-Z0-9-]+\.[a-zA-Z]{2,}$'
     return re.match(pattern, email) is not None
+
+
+# ------------------------------
+# Filename sanitization helpers
+# ------------------------------
+
+_WINDOWS_RESERVED_BASENAMES = {
+    # Device names without extensions (case-insensitive match on stem only)
+    'CON', 'PRN', 'AUX', 'NUL',
+    *(f'COM{i}' for i in range(1, 10)),
+    *(f'LPT{i}' for i in range(1, 10)),
+}
+
+_WINDOWS_INVALID_CHARS = set('<>:"\\|?*')  # plus control chars 0x00-0x1F handled separately
+
+def _percent_encode_byte(b: int) -> str:
+    return f'%{b:02X}'
+
+def sanitize_windows_filename(name: str) -> tuple[str, bool]:
+    """Return a Windows-safe filename by percent-encoding illegal constructs.
+
+    Highlights (Windows relevance):
+      * Control chars (0x00-0x1F) encoded.
+      * Characters in _WINDOWS_INVALID_CHARS encoded.
+      * Trailing spaces and periods encoded.
+      * Existing '%' encoded only if another change occurs (to avoid unnecessary churn).
+      * Reserved device names (CON, PRN, AUX, NUL, COM1-9, LPT1-9) including when followed
+        by a dot/extension have their final character encoded.
+        (e.g. "AUX" -> "AU%58", "AUX.txt" -> "AU%58.txt").
+
+    Returns (sanitized_name, modified_flag).
+    """
+    original = name
+    if not name:
+        return name, False
+
+    # Reserved device name detection (with or without extension). We encode the last character
+    # of the reserved token so that the resulting string no longer triggers Windows device name rules.
+    upper_name = name.upper()
+    reserved_index: int | None = None
+    for base in _WINDOWS_RESERVED_BASENAMES:
+        if upper_name == base or upper_name.startswith(base + '.'):
+            reserved_index = len(base) - 1
+            break
+
+    # Determine indexes to encode.
+    encode_indexes: set[int] = set()
+    length = len(name)
+    for idx, ch in enumerate(name):
+        code = ord(ch)
+        if code < 0x20:
+            encode_indexes.add(idx)
+        elif ch in _WINDOWS_INVALID_CHARS:
+            encode_indexes.add(idx)
+        elif ch == '\\':  # already included above but explicit for clarity
+            encode_indexes.add(idx)
+        # NOTE: '%' handled later globally
+
+    # Encode trailing spaces and dots
+    t = length - 1
+    while t >= 0 and name[t] in (' ', '.'):
+        encode_indexes.add(t)
+        t -= 1
+
+    # Reserved device name last character encoding (with or without extension).
+    if reserved_index is not None:
+        encode_indexes.add(reserved_index)
+
+    modified = bool(encode_indexes)
+
+    if not modified:
+        # Nothing to do; leave '%' untouched.
+        return name, False
+
+    # Build output encoding '%' first.
+    out_chars: list[str] = []
+    for idx, ch in enumerate(name):
+        if ch == '%':
+            out_chars.append('%25')
+            continue
+        if idx in encode_indexes:
+            out_chars.append(_percent_encode_byte(ord(ch)))
+        else:
+            out_chars.append(ch)
+
+    sanitized = ''.join(out_chars)
+    return sanitized, sanitized != original
+
+
+def is_path_within_directory(base_dir: str, target_path: str) -> bool:
+    """Return True if target_path is within base_dir (after resolving symlinks)."""
+    base_real = os.path.realpath(base_dir)
+    target_real = os.path.realpath(target_path)
+    # Ensure base path ends with separator for prefix test to avoid /foo/bar vs /foo/barista
+    if not base_real.endswith(os.path.sep):
+        base_real += os.path.sep
+    return target_real.startswith(base_real)
+
+
+def sanitize_windows_relpath(rel_path: str, verbose: bool = False, printer=None) -> tuple[str, bool]:
+    """Sanitize a relative path intended for Windows downloads.
+
+    Splits only on forward slashes (logical separators we introduce) so that any
+    backslashes present in remote filenames are treated as data and percent-encoded.
+
+    Returns (sanitized_rel_path, modified_flag).
+    """
+    if os.name != 'nt':  # no-op on non-Windows
+        return rel_path, False
+    if not rel_path:
+        return rel_path, False
+    components = rel_path.split('/') if '/' in rel_path else [rel_path]
+    out_parts: list[str] = []
+    modified_any = False
+    if printer is None:
+        def noop_printer(msg):
+            pass
+        printer = noop_printer
+    original_components: list[str] = []
+    for comp in components:
+        original_components.append(comp)
+        sanitized, modified = sanitize_windows_filename(comp)
+        out_parts.append(sanitized)
+        modified_any = modified_any or modified
+    result_path = os.path.join(*out_parts)
+    if verbose and modified_any:
+        original_path_display = os.path.join(*original_components)
+        printer(f'windows path sanitized: {original_path_display} -> {result_path}')
+    return result_path, modified_any
+
+def is_windows() -> bool:
+    return (
+        platform.system().lower() == "windows"
+        or sys.platform.startswith("win")
+    )
+
+
+def sanitize_filepath(filepath: str, avoid_colon: bool = False) -> str:
+    """
+    Sanitizes only the filename part of a full file path, leaving the directory path intact.
+
+    This is useful when you need to ensure the filename is safe for filesystem use
+    without modifying the directory structure. Typically used before creating files
+    or directories to prevent invalid filename characters.
+
+    Args:
+        filepath (str): The full file path to sanitize.
+        avoid_colon (bool): If True, colon ':' in the filename will be percent-encoded
+            for macOS compatibility. Defaults to False.
+
+    Returns:
+        str: The sanitized file path with the filename portion percent-encoded as needed.
+    """
+    parent_dir = os.path.dirname(filepath)
+    filename = os.path.basename(filepath)
+    sanitized_filename = sanitize_filename(filename, avoid_colon)
+    return os.path.join(parent_dir, sanitized_filename)
+
+
+def sanitize_filename(name: str, avoid_colon: bool = False) -> str:
+    """
+    Sanitizes a filename by replacing invalid characters with percent-encoded values.
+    This function is designed to be compatible with both Windows and POSIX systems.
+
+    Args:
+        name (str): The original string to sanitize.
+        avoid_colon (bool): If True, colon ':' will be percent-encoded.
+
+    Returns:
+        str: A sanitized version of the filename.
+    """
+    original = name
+    if is_windows():
+        sanitized = sanitize_filename_windows(name)
+    else:
+        sanitized = sanitize_filename_posix(name, avoid_colon)
+
+    if sanitized != original:
+        warnings.warn(
+            f"Filename sanitized: original='{original}' sanitized='{sanitized}'",
+            UserWarning,
+            stacklevel=2
+        )
+
+    return sanitized
+
+
+def unsanitize_filename(name: str) -> str:
+    """
+    Reverses percent-encoding of the form %XX back to original characters.
+    Works for filenames sanitized by sanitize_filename (Windows or POSIX).
+
+    Args:
+        name (str): Sanitized filename string with %XX encodings.
+
+    Returns:
+        str: Original filename with all %XX sequences decoded.
+    """
+    if '%' in name:
+        if re.search(r'%[0-9A-Fa-f]{2}', name):
+            warnings.warn(
+                "Filename contains percent-encoded sequences that will be decoded.",
+                UserWarning,
+                stacklevel=2
+            )
+    def decode_match(match):
+        hex_value = match.group(1)
+        return chr(int(hex_value, 16))
+
+    return re.sub(r'%([0-9A-Fa-f]{2})', decode_match, name)
+
+
+def sanitize_filename_windows(name: str) -> str:
+    r"""
+    Replaces Windows-invalid filename characters with percent-encoded values.
+    Characters replaced: < > : " / \ | ? * %
+
+    Args:
+        name (str): The original string.
+
+    Returns:
+        str: A sanitized version safe for filesystem use.
+    """
+    # Encode `%` so that it's possible to round-trip (i.e. via `unsanitize_filename`)
+    invalid_chars = r'[<>:"/\\|?*\x00-\x1F%]'
+
+    def encode(char):
+        return f'%{ord(char.group()):02X}'
+
+    # Replace invalid characters
+    name = re.sub(invalid_chars, encode, name)
+
+    # Remove trailing dots or spaces (not allowed in Windows filenames)
+    return name.rstrip(' .')
+
+
+def sanitize_filename_posix(name: str, avoid_colon: bool = False) -> str:
+    """
+    Sanitizes filenames for Linux, BSD, and Unix-like systems.
+
+    - Percent-encodes forward slash '/' (always)
+    - Optionally percent-encodes colon ':' for macOS compatibility
+
+    Args:
+        name (str): Original filename string.
+        avoid_colon (bool): If True, colon ':' will be encoded.
+
+    Returns:
+        str: Sanitized filename safe for POSIX systems.
+    """
+    # Build regex pattern dynamically
+    chars_to_encode = r'/'
+    if avoid_colon:
+        chars_to_encode += ':'
+
+    pattern = f'[{re.escape(chars_to_encode)}]'
+
+    def encode_char(match):
+        return f'%{ord(match.group()):02X}'
+
+    return re.sub(pattern, encode_char, name)
