@@ -1,10 +1,6 @@
 from copy import deepcopy
 
-from internetarchive import get_session
-from internetarchive.cli import ia_list
-from tests.conftest import IaRequestsMock
-
-SESSION = get_session()
+from tests.conftest import IaRequestsMock, ia_call
 
 NASA_FILES = {
     'NASAarchiveLogo.jpg',
@@ -17,13 +13,13 @@ NASA_FILES = {
 
 
 def test_ia_list(capsys, nasa_mocker):
-    ia_list.main(['list', 'nasa'], SESSION)
+    ia_call(['ia', 'list', 'nasa'])
     out, err = capsys.readouterr()
     assert {l for l in out.split('\n') if l} == NASA_FILES
 
 
 def test_ia_list_verbose(capsys, nasa_mocker):
-    ia_list.main(['list', '--verbose', 'nasa'], SESSION)
+    ia_call(['ia', 'list', '--verbose', 'nasa'])
 
     out, err = capsys.readouterr()
     _nasa_files = deepcopy(NASA_FILES)
@@ -32,7 +28,7 @@ def test_ia_list_verbose(capsys, nasa_mocker):
 
 
 def test_ia_list_all(capsys, nasa_mocker):
-    ia_list.main(['list', '--all', 'nasa'], SESSION)
+    ia_call(['ia', 'list', '--all', 'nasa'])
 
     out, err = capsys.readouterr()
     out = [l for l in out.split('\n') if l]
@@ -42,7 +38,7 @@ def test_ia_list_all(capsys, nasa_mocker):
 
 
 def test_ia_list_location(capsys, nasa_mocker):
-    ia_list.main(['list', '--location', '--glob', '*meta.xml', 'nasa'], SESSION)
+    ia_call(['ia', 'list', '--location', '--glob', '*meta.xml', 'nasa'])
     out, err = capsys.readouterr()
     assert out == 'https://archive.org/download/nasa/nasa_meta.xml\n'
 
@@ -50,28 +46,27 @@ def test_ia_list_location(capsys, nasa_mocker):
 def test_ia_list_columns(capsys):
     with IaRequestsMock() as rsps:
         rsps.add_metadata_mock('nasa')
-        ia_list.main(['list', '--columns', 'name,md5', '--glob', '*meta.xml', 'nasa'],
-                     SESSION)
+        ia_call(['ia', 'list', '--columns', 'name,md5', '--glob', '*meta.xml', 'nasa'])
 
     out, err = capsys.readouterr()
     assert out == 'nasa_meta.xml\t0e339f4a29a8bc42303813cbec9243e5\n'
 
     with IaRequestsMock() as rsps:
         rsps.add_metadata_mock('nasa')
-        ia_list.main(['list', '--columns', 'md5', '--glob', '*meta.xml', 'nasa'], SESSION)
+        ia_call(['ia', 'list', '--columns', 'md5', '--glob', '*meta.xml', 'nasa'])
 
     out, err = capsys.readouterr()
     assert out == '0e339f4a29a8bc42303813cbec9243e5\n'
 
 
 def test_ia_list_glob(capsys, nasa_mocker):
-    ia_list.main(['list', '--glob', '*torrent', 'nasa'], SESSION)
+    ia_call(['ia', 'list', '--glob', '*torrent', 'nasa'])
     out, err = capsys.readouterr()
     assert out == 'nasa_archive.torrent\n'
 
 
 def test_ia_list_format(capsys, nasa_mocker):
-    ia_list.main(['list', '--format', 'Metadata', 'nasa'], SESSION)
+    ia_call(['ia', 'list', '--format', 'Metadata', 'nasa'])
 
     out, err = capsys.readouterr()
     expected_output = {
@@ -85,10 +80,7 @@ def test_ia_list_format(capsys, nasa_mocker):
 def test_ia_list_non_existing(capsys):
     with IaRequestsMock() as rsps:
         rsps.add_metadata_mock('nasa', body='{}')
-        try:
-            ia_list.main(['list', 'nasa'], SESSION)
-        except SystemExit as exc:
-            assert exc.code == 1
+        ia_call(['ia', 'list', 'nasa'], expected_exit_code=1)
 
     out, err = capsys.readouterr()
     assert out == ''
